@@ -4,7 +4,7 @@ from ml.ml40.features.functionalities.functionality import Functionality
 
 
 class ForestPlanningEvaluation(Functionality):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="fml40", name="", identifier="", parent=None):
         """Initializes the object.
 
         :param name: Object name
@@ -12,8 +12,8 @@ class ForestPlanningEvaluation(Functionality):
 
         """
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def evaluateInventoryData(self):
         pass
