@@ -3,10 +3,10 @@ from ml.ml40.features.properties.values.documents.jobs.job import Job
 
 
 class ClearsJobs(Functionality):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="ml40", name="", identifier="", parent=None):
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def clear(self, job: Job) -> bool:
         pass
